Class: Google::Apis::ManagedidentitiesV1alpha1::DailyCycle
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1alpha1::DailyCycle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb
Overview
Time window specified for daily operations.
Instance Attribute Summary collapse
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::ManagedidentitiesV1alpha1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyCycle
constructor
A new instance of DailyCycle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyCycle
Returns a new instance of DailyCycle.
325 326 327 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
316 317 318 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 316 def duration @duration end |
#start_time ⇒ Google::Apis::ManagedidentitiesV1alpha1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
323 324 325 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 323 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
330 331 332 333 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 330 def update!(**args) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |