Class: Google::Apis::ManagedidentitiesV1alpha1::GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb

Overview

SloEligibility is a tuple containing eligibility value: true if an instance is eligible for SLO calculation or false if it should be excluded from all SLO- related calculations along with a user-defined reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility

Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.



1314
1315
1316
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligibleBoolean Also known as: eligible?

Whether an instance is eligible or ineligible. Corresponds to the JSON property eligible

Returns:

  • (Boolean)


1305
1306
1307
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1305

def eligible
  @eligible
end

#reasonString

User-defined reason for the current value of instance eligibility. Usually, this can be directly mapped to the internal state. An empty reason is allowed. Corresponds to the JSON property reason

Returns:

  • (String)


1312
1313
1314
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1312

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1319
1320
1321
1322
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1319

def update!(**args)
  @eligible = args[:eligible] if args.key?(:eligible)
  @reason = args[:reason] if args.key?(:reason)
end