Class: Google::Apis::ManagedidentitiesV1alpha1::ListBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb

Overview

ListBackupsResponse is the response message for ListBackups method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackupsResponse

Returns a new instance of ListBackupsResponse.



1452
1453
1454
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsArray<Google::Apis::ManagedidentitiesV1alpha1::Backup>

A list of Cloud AD backups in the domain. Corresponds to the JSON property backups



1439
1440
1441
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1439

def backups
  @backups
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1445
1446
1447
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1445

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1450
1451
1452
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1450

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1457
1458
1459
1460
1461
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1457

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end