Class: Google::Apis::ManagedidentitiesV1alpha1::ListDomainsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDomainsResponse

Returns a new instance of ListDomainsResponse.



1484
1485
1486
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainsArray<Google::Apis::ManagedidentitiesV1alpha1::Domain>

A list of Managed Identities Service domains in the project. Corresponds to the JSON property domains



1471
1472
1473
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1471

def domains
  @domains
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1477

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1482
1483
1484
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1482

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1489
1490
1491
1492
1493
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1489

def update!(**args)
  @domains = args[:domains] if args.key?(:domains)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end