Class: Google::Apis::ManagedidentitiesV1alpha1::ListSqlIntegrationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1alpha1::ListSqlIntegrationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb
Overview
ListSQLIntegrationsResponse is the response message for ListSQLIntegrations method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#sql_integrations ⇒ Array<Google::Apis::ManagedidentitiesV1alpha1::SqlIntegration>
A list of SQLIntegrations of a domain.
-
#unreachable ⇒ Array<String>
A list of locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSqlIntegrationsResponse
constructor
A new instance of ListSqlIntegrationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSqlIntegrationsResponse
Returns a new instance of ListSqlIntegrationsResponse.
1608 1609 1610 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
1596 1597 1598 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1596 def next_page_token @next_page_token end |
#sql_integrations ⇒ Array<Google::Apis::ManagedidentitiesV1alpha1::SqlIntegration>
A list of SQLIntegrations of a domain.
Corresponds to the JSON property sqlIntegrations
1601 1602 1603 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1601 def sql_integrations @sql_integrations end |
#unreachable ⇒ Array<String>
A list of locations that could not be reached.
Corresponds to the JSON property unreachable
1606 1607 1608 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1606 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1613 1614 1615 1616 1617 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1613 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sql_integrations = args[:sql_integrations] if args.key?(:sql_integrations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |