Class: Google::Apis::ManagedidentitiesV1alpha1::Peering
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1alpha1::Peering
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb
Overview
Represents a Managed Microsoft Identities Peering.
Instance Attribute Summary collapse
-
#authorized_network ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#domain_resource ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Peering
constructor
A new instance of Peering.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Peering
Returns a new instance of Peering.
1980 1981 1982 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized_network ⇒ String
Required. The full names of the Google Compute Engine networks to which the instance is connected. Caller
needs to make sure that CIDR subnets do not overlap between networks, else
peering creation will fail.
Corresponds to the JSON property authorizedNetwork
1938 1939 1940 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1938 def @authorized_network end |
#create_time ⇒ String
Output only. The time the instance was created.
Corresponds to the JSON property createTime
1943 1944 1945 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1943 def create_time @create_time end |
#domain_resource ⇒ String
Required. Full domain resource path for the Managed AD Domain involved in
peering. The resource path should be in the form: projects/project_id/
locations/global/domains/domain_name`
Corresponds to the JSON propertydomainResource`
1950 1951 1952 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1950 def domain_resource @domain_resource end |
#labels ⇒ Hash<String,String>
Optional. Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
1955 1956 1957 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1955 def labels @labels end |
#name ⇒ String
Output only. Unique name of the peering in this scope including projects and
location using the form: projects/project_id/locations/global/peerings/
peering_id`.
Corresponds to the JSON propertyname`
1962 1963 1964 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1962 def name @name end |
#state ⇒ String
Output only. The current state of this Peering.
Corresponds to the JSON property state
1967 1968 1969 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1967 def state @state end |
#status_message ⇒ String
Output only. Additional information about the current status of this peering,
if available.
Corresponds to the JSON property statusMessage
1973 1974 1975 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1973 def @status_message end |
#update_time ⇒ String
Output only. Last update time.
Corresponds to the JSON property updateTime
1978 1979 1980 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1978 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1985 def update!(**args) @authorized_network = args[:authorized_network] if args.key?(:authorized_network) @create_time = args[:create_time] if args.key?(:create_time) @domain_resource = args[:domain_resource] if args.key?(:domain_resource) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @status_message = args[:status_message] if args.key?(:status_message) @update_time = args[:update_time] if args.key?(:update_time) end |