Class: Google::Apis::ManagedidentitiesV1alpha1::ReconfigureTrustRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReconfigureTrustRequest

Returns a new instance of ReconfigureTrustRequest.



2100
2101
2102
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#trust_propGoogle::Apis::ManagedidentitiesV1alpha1::TrustProp

Represents a relationship between two domains which makes it possible for users in one domain to be authenticated by a dc in another domain. Refer https: //docs.microsoft.com/en-us/previous-versions/windows/it-pro/windows-server- 2008-R2-and-2008/cc731335(v%3dws.10) If the trust is being changed, it will be placed into the UPDATING state, which indicates that the resource is being reconciled. At this point, Get will reflect an intermediate state. Corresponds to the JSON property trust



2098
2099
2100
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2098

def trust_prop
  @trust_prop
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2105
2106
2107
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2105

def update!(**args)
  @trust_prop = args[:trust_prop] if args.key?(:trust_prop)
end