Class: Google::Apis::ManagedidentitiesV1alpha1::SqlIntegration
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1alpha1::SqlIntegration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb
Overview
Represents the SQL instance integrated with AD.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
The unique name of the sql integration in the form of
projects/project_id/ locations/global/domains/domain_name/sqlIntegrations/sql_integration`Corresponds to the JSON propertyname`. -
#sql_instance ⇒ String
The full resource name of an integrated sql instance Corresponds to the JSON property
sqlInstance. -
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlIntegration
constructor
A new instance of SqlIntegration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlIntegration
Returns a new instance of SqlIntegration.
2191 2192 2193 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the instance was created.
Corresponds to the JSON property createTime
2168 2169 2170 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2168 def create_time @create_time end |
#name ⇒ String
The unique name of the sql integration in the form of projects/project_id/
locations/global/domains/domain_name/sqlIntegrations/sql_integration`
Corresponds to the JSON propertyname`
2174 2175 2176 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2174 def name @name end |
#sql_instance ⇒ String
The full resource name of an integrated sql instance
Corresponds to the JSON property sqlInstance
2179 2180 2181 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2179 def sql_instance @sql_instance end |
#state ⇒ String
Output only. The current state of the managed OU.
Corresponds to the JSON property state
2184 2185 2186 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2184 def state @state end |
#update_time ⇒ String
Output only. Last update time for this SQL instance.
Corresponds to the JSON property updateTime
2189 2190 2191 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2189 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2196 2197 2198 2199 2200 2201 2202 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2196 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @sql_instance = args[:sql_instance] if args.key?(:sql_instance) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |