Class: Google::Apis::ManagedidentitiesV1alpha1::TrustProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb

Overview

Represents a relationship between two domains which makes it possible for users in one domain to be authenticated by a dc in another domain. Refer https: //docs.microsoft.com/en-us/previous-versions/windows/it-pro/windows-server- 2008-R2-and-2008/cc731335(v%3dws.10) If the trust is being changed, it will be placed into the UPDATING state, which indicates that the resource is being reconciled. At this point, Get will reflect an intermediate state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrustProp

Returns a new instance of TrustProp.



2477
2478
2479
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2419
2420
2421
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2419

def create_time
  @create_time
end

#last_known_trust_connected_heartbeat_timeString

Output only. The last heartbeat time when the trust was known to be connected. Corresponds to the JSON property lastKnownTrustConnectedHeartbeatTime

Returns:

  • (String)


2424
2425
2426
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2424

def last_known_trust_connected_heartbeat_time
  @last_known_trust_connected_heartbeat_time
end

#selective_authenticationBoolean Also known as: selective_authentication?

The trust authentication type which decides whether the trusted side has forest/domain wide access or selective access to approved set of resources. Corresponds to the JSON property selectiveAuthentication

Returns:

  • (Boolean)


2430
2431
2432
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2430

def selective_authentication
  @selective_authentication
end

#stateString

Output only. The current state of this trust. Corresponds to the JSON property state

Returns:

  • (String)


2436
2437
2438
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2436

def state
  @state
end

#state_descriptionString

Output only. Additional information about the current state of this trust, if available. Corresponds to the JSON property stateDescription

Returns:

  • (String)


2442
2443
2444
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2442

def state_description
  @state_description
end

#target_dns_ip_addressesArray<String>

The target dns server ip addresses which can resolve the remote domain involved in trust. Corresponds to the JSON property targetDnsIpAddresses

Returns:

  • (Array<String>)


2448
2449
2450
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2448

def target_dns_ip_addresses
  @target_dns_ip_addresses
end

#target_domain_nameString

The fully qualified target domain name which will be in trust with current domain. Corresponds to the JSON property targetDomainName

Returns:

  • (String)


2454
2455
2456
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2454

def target_domain_name
  @target_domain_name
end

#trust_directionString

The trust direction decides the current domain is trusted, trusting or both. Corresponds to the JSON property trustDirection

Returns:

  • (String)


2459
2460
2461
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2459

def trust_direction
  @trust_direction
end

#trust_handshake_secretString

Input only, and will not be stored. The trust secret used for handshake with target domain. Corresponds to the JSON property trustHandshakeSecret

Returns:

  • (String)


2465
2466
2467
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2465

def trust_handshake_secret
  @trust_handshake_secret
end

#trust_typeString

The type of trust represented by the trust resource. Corresponds to the JSON property trustType

Returns:

  • (String)


2470
2471
2472
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2470

def trust_type
  @trust_type
end

#update_timeString

Output only. Last update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2475
2476
2477
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2475

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2482

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @last_known_trust_connected_heartbeat_time = args[:last_known_trust_connected_heartbeat_time] if args.key?(:last_known_trust_connected_heartbeat_time)
  @selective_authentication = args[:selective_authentication] if args.key?(:selective_authentication)
  @state = args[:state] if args.key?(:state)
  @state_description = args[:state_description] if args.key?(:state_description)
  @target_dns_ip_addresses = args[:target_dns_ip_addresses] if args.key?(:target_dns_ip_addresses)
  @target_domain_name = args[:target_domain_name] if args.key?(:target_domain_name)
  @trust_direction = args[:trust_direction] if args.key?(:trust_direction)
  @trust_handshake_secret = args[:trust_handshake_secret] if args.key?(:trust_handshake_secret)
  @trust_type = args[:trust_type] if args.key?(:trust_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end