Class: Google::Apis::ManagedidentitiesV1alpha1::ListPeeringsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1alpha1::ListPeeringsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb
Overview
ListPeeringsResponse is the response message for ListPeerings method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#peerings ⇒ Array<Google::Apis::ManagedidentitiesV1alpha1::Peering>
A list of Managed Identities Service Peerings in the project.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPeeringsResponse
constructor
A new instance of ListPeeringsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPeeringsResponse
Returns a new instance of ListPeeringsResponse.
1575 1576 1577 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
1563 1564 1565 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1563 def next_page_token @next_page_token end |
#peerings ⇒ Array<Google::Apis::ManagedidentitiesV1alpha1::Peering>
A list of Managed Identities Service Peerings in the project.
Corresponds to the JSON property peerings
1568 1569 1570 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1568 def peerings @peerings end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1573 1574 1575 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1573 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1580 1581 1582 1583 1584 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 1580 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @peerings = args[:peerings] if args.key?(:peerings) @unreachable = args[:unreachable] if args.key?(:unreachable) end |