Class: Google::Apis::ManagedidentitiesV1alpha1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1alpha1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1alpha1/classes.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb,
lib/google/apis/managedidentities_v1alpha1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::ManagedidentitiesV1alpha1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
2226 2227 2228 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
2212 2213 2214 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2212 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
2217 2218 2219 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2217 def duration @duration end |
#start_time ⇒ Google::Apis::ManagedidentitiesV1alpha1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
2224 2225 2226 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2224 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2231 2232 2233 2234 2235 |
# File 'lib/google/apis/managedidentities_v1alpha1/classes.rb', line 2231 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |